@@ -28,7 +28,7 @@ import os
 
 from hc_upgrade_tools import __version__
 from hc_upgrade_tools import subcmd
-from hc_upgrade_tools import donwload_artifacts
+from hc_upgrade_tools import handl_upgrade
 from hc_upgrade_tools import utility as util
 
 __author__ = "shixukai"
@@ -104,7 +104,7 @@ def parse_args(args):
     parser.set_defaults(func=toplevel_function)
 
     subcmd.init_subparser(subparsers)
-    donwload_artifacts.init_subparser(subparsers)
+    handl_upgrade.init_subparser(subparsers)
 
     final_args = parser.parse_args(args)
     final_args.func(final_args)
