@@ -118,9 +118,9 @@ def download_artifact(artifact_host, artifact_port, remote_path, project_id, ori
             return artifact_path
 
     except Exception as error:
-        print(f"download artifact failed, error is {error}")
-
-        return None
+        logger.error(f"download artifact failed, error is {error}")
+        # exit process
+        exit(1)
 
 
 def handle_artifacts(source_file_path, target_dir, source_sub_folder=None):
@@ -206,7 +206,12 @@ def link_current_to_new_release(link_current_symbol, target_release_dir):
         os.remove(link_current_symbol)
 
     # link current to new release
-    os.symlink(target_release_dir, link_current_symbol)
+    # if link failed, exit process
+    try:
+        os.symlink(target_release_dir, link_current_symbol)
+    except Exception as error:
+        print(f"link current to new release failed, error is {error}")
+        exit(1)
 
 
 def handle_extra_links(args):
@@ -226,6 +231,38 @@ def handle_extra_links(args):
         os.symlink(source_path, link_symbolic)
 
 
+def restart_docker_container(args):
+    if not args.restart_docker:
+        return
+
+    logger = get_logger()
+
+    # read docker-compose.yml from current symbolic
+    docker_compose_file = os.path.join(args.project_dir, "current", "docker-compose.yml")
+    container_name = None
+    with open(docker_compose_file, "r") as f:
+        for line in f.readlines():
+            if "container_name" in line:
+                container_name = line.split(":")[1].strip()
+                break
+
+    if not container_name:
+        print(f"get container name from docker-compose.yml failed")
+        return False
+
+    # docker stop container_name and docker rm container_name
+    os.system(f"docker stop {container_name}")
+    os.system(f"docker rm {container_name}")
+
+    # change dir to current symbolic and docker-compose up -d
+    os.chdir(os.path.join(args.project_dir, "current"))
+    # show current symbolic target dir
+    logger.info(f"current symbolic target dir is {os.path.realpath(os.path.join(args.project_dir, 'current'))}")
+    os.system("docker-compose up -d")
+
+    logger.info(f"restart docker container {container_name} success")
+
+
 if __name__ == "__main__":
     #download url :http://10.0.20.115:7070/api/githook/request-artifacts
     artifacts_path =  download_artifact("10.0.20.115", 7070, "/api/githook/request-artifacts", 196, "/tmp/hc_upgrade_tools/artifacts/", "test.tar.gz")
